@@ -19,6 +19,7 @@ class SearchModel : public AbstractYTMusicModel
 public:
     enum Type {
         Artist,
+        ArtistsDisplayString,
         Album,
         Playlist,
         Song,
@@ -31,7 +32,8 @@ public:
         Type,
         VideoId,
         Artists,
-        RadioPlaylistId
+        RadioPlaylistId,
+        ThumbnailUrl
     };
 
     explicit SearchModel(QObject *parent = nullptr);
@@ -47,7 +49,7 @@ public:
     Q_INVOKABLE void triggerItem(int row);
 
     Q_SIGNAL void openAlbum(const QString &browseId);
-    Q_SIGNAL void openArtist(const QString &browseId);
+    Q_SIGNAL void openArtist(const QString &browseId,const QString &radioId, const QString &shuffleId);
     Q_SIGNAL void openPlaylist(const QString &browseId);
     Q_SIGNAL void openSong(const QString &videoId);
     Q_SIGNAL void openVideo(const QString &videoId, const QString &title);
